7495791f0d935716eb5a6231e11ba833ef327aed
angie
  Thu Apr 6 10:21:25 2017 -0700
Oops, forgot to implement maxOutRows for annoStreamTab!  Thx Chris Lee.  refs #12216

diff --git src/inc/annoStreamTab.h src/inc/annoStreamTab.h
index e9cb92f..2b81a5f 100644
--- src/inc/annoStreamTab.h
+++ src/inc/annoStreamTab.h
@@ -1,13 +1,15 @@
 /* annoStreamTab -- subclass of annoStreamer for tab-separated text files/URLs */
 
 #ifndef ANNOSTREAMTAB_H
 #define ANNOSTREAMTAB_H
 
 #include "annoStreamer.h"
 
 struct annoStreamer *annoStreamTabNew(char *fileOrUrl, struct annoAssembly *aa,
-				      struct asObject *asObj);
+				      struct asObject *asObj, int maxOutRows);
 /* Create an annoStreamer (subclass) object from a tab-separated text file/URL
  * whose columns are described by asObj (possibly excepting bin column at beginning). */
 
 #endif//ndef ANNOSTREAMTAB_H
@@ -1,13 +1,15 @@
 /* Create an annoStreamer (subclass) object from a tab-separated text file/URL
- * whose columns are described by asObj (possibly excepting bin column at beginning). */
+ * whose columns are described by asObj (possibly excepting bin column at beginning).
+ * If maxOutRows is greater than 0 then it is an upper limit on the number of rows
+ * that the streamer will produce. */
 
 #endif//ndef ANNOSTREAMTAB_H